==> Flask-Sitemap-Domain-0.2.1.dev20150105.tar.gz: Flask-Sitemap-Domain-0.2.1.dev20150105/setup.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Flask-Sitemap
# Copyright (C) 2014, 2015 CERN.
#
# Flask-Sitemap is free software; you can redistribute it and/or modify
# it under the terms of the Revised BSD License; see LICENSE file for
# more details.

import os
import re
import sys

from setuptools import setup

needs_pytest = set(['pytest', 'test', 'ptr']).intersection(sys.argv)
pytest_runner = ['pytest-runner'] if needs_pytest else []

# Get the version string. Cannot be done with import!
with open(os.path.join('flask_sitemap', 'version.py'), 'rt') as f:
    version = re.search(
        '__version__\s*=\s*"(?P<version>.*)"\n',
        f.read()
    ).group('version')

extras_require = {
    'docs': ['sphinx'],
    'cli': ['Flask-Script'],
}

tests_require = [
    'pytest-cache>=1.0',
    'pytest-cov>=2.2.0',
    'pytest-pep8>=1.0.6',
    'pytest>=2.8.5',
    'coverage',
]

# Extend dependencies with extra packages
for key, extra in extras_require.items():
    if key != 'docs':
        tests_require += extra
        extras_require['docs'] += extra

setup(
    name='Flask-Sitemap-Domain',
    version=version,
    url='https://github.com/egillingham/flask-sitemap/',
    license='BSD',
    author='Invenio collaboration + Erin Gillingham',
    author_email='e.gillingham@gmail.com',
    description='Flask extension that helps with sitemap generation.',
    long_description=open('README.md').read(),
    packages=['flask_sitemap'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    setup_requires=pytest_runner,
    install_requires=[
        'Flask',
        'blinker',
    ],
    extras_require=extras_require,
    tests_require=tests_require,
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Flask',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Development Status :: 5 - Production/Stable'
    ],
)

==> Flask-Sitemap-Domain-0.2.2.tar.gz: Flask-Sitemap-Domain-0.2.2/setup.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Flask-Sitemap
# Copyright (C) 2014, 2015 CERN.
#
# Flask-Sitemap is free software; you can redistribute it and/or modify
# it under the terms of the Revised BSD License; see LICENSE file for
# more details.

import os
import re
import sys

from setuptools import setup

needs_pytest = set(['pytest', 'test', 'ptr']).intersection(sys.argv)
pytest_runner = ['pytest-runner'] if needs_pytest else []

# Get the version string. Cannot be done with import!
with open(os.path.join('flask_sitemap_domain', 'version.py'), 'rt') as f:
    version = re.search(
        '__version__\s*=\s*"(?P<version>.*)"\n',
        f.read()
    ).group('version')

extras_require = {
    'docs': ['sphinx'],
    'cli': ['Flask-Script'],
}

tests_require = [
    'pytest-cache>=1.0',
    'pytest-cov>=2.2.0',
    'pytest-pep8>=1.0.6',
    'pytest>=2.8.5',
    'coverage',
]

# Extend dependencies with extra packages
for key, extra in extras_require.items():
    if key != 'docs':
        tests_require += extra
        extras_require['docs'] += extra

setup(
    name='Flask-Sitemap-Domain',
    version=version,
    url='https://github.com/egillingham/flask-sitemap/',
    license='BSD',
    author='Invenio collaboration + Erin Gillingham',
    author_email='e.gillingham@gmail.com',
    description='Flask extension that helps with sitemap generation.',
    long_description=open('README.rst').read(),
    packages=['flask_sitemap_domain'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    setup_requires=pytest_runner,
    install_requires=[
        'Flask',
        'blinker',
    ],
    extras_require=extras_require,
    tests_require=tests_require,
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Flask',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Development Status :: 5 - Production/Stable'
    ],
)
